/* SPDX-License-Identifier: GPL-2.0-only */

#ifndef _BAYTRAIL_ACPI_H_
#define _BAYTRAIL_ACPI_H_

#include <acpi/acpi.h>

#endif /* _BAYTRAIL_ACPI_H_ */
